@@ -10,8 +10,8 @@ describe("less factory", function () {
       "bbedde65-07b1-451a-9ba1-afe28b07786d";
 
     this.factory = proxyquire("./less", {
-      "../actual-and-expected-message-values": this
-        .fakeActualAndExpectedMessageValues,
+      "../actual-and-expected-message-values":
+        this.fakeActualAndExpectedMessageValues,
     });
 
     this.fakeReferee = {
@@ -51,7 +51,7 @@ describe("less factory", function () {
     it("is '${customMessage}Expected ${actual} to be less than ${expected}'", function () {
       assert.equal(
         this.options.assertMessage,
-        "${customMessage}Expected ${actual} to be less than ${expected}"
+        "${customMessage}Expected ${actual} to be less than ${expected}",
       );
     });
   });
@@ -60,7 +60,7 @@ describe("less factory", function () {
     it("is '${customMessage}Expected ${actual} to be greater than or equal to ${expected}'", function () {
       assert.equal(
         this.options.refuteMessage,
-        "${customMessage}Expected ${actual} to be greater than or equal to ${expected}"
+        "${customMessage}Expected ${actual} to be greater than or equal to ${expected}",
       );
     });
   });
@@ -75,7 +75,7 @@ describe("less factory", function () {
     it("delegates to '../actual-and-expected-message-values'", function () {
       assert.equal(
         this.options.values,
-        this.fakeActualAndExpectedMessageValues
+        this.fakeActualAndExpectedMessageValues,
       );
     });
   });
